import ajax from '../util/ajax'
import api from '../util/api'

export default {
  namespaced: true,
  state: {
    activity: {},
    user: '4',
    detail: {},
    toplist: [],
    list: [],
  },
  mutations: {
    updateActivity (state, data) {
      state.activity = data || {}
    },
    updateUser (state, data) {
      state.user = data
    },
    updateDetail (state, data) {
      state.detail = data || {}
    },
    updateList (state, data) {
      state.list = data || []
    },
    updateTopList (state, data) {
      state.toplist = data || []
    },
  },
  actions: {
    getActivity ({ commit }, {actid}) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.info,
          urlData: {
            actid: actid,
          }
        }).then((res) => {
          commit('updateActivity', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getMember ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.detail,
          urlData: {
            actid: payload.actid,
            memberid: payload.memberid,
          },
        }).then((res) => {
          commit('updateDetail', res)
          resolve(res)
        }).catch(reject)
      })
    },
    vote (m, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.vote,
          urlData: {
            actid: payload.actid,
            memberid: payload.memberid,
          },
          queryData: {
            openid: payload.openid,
          }
        }).then((res) => {
          resolve(res)
        }).catch(reject)
      })
    },
    voteMember ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.registe,
          urlData: {
            actid: payload.actid,
          },
          queryData: {
            ...payload,
          }
        }).then((res) => {
          commit('updateDetail', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getUser ({ commit }, { code }) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.user,
          urlData: {
            code: code,
          },
        }).then((res) => {
          commit('updateUser', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.list,
          queryData: {
            ...payload,
            tab: 1,
          },
        }).then((res) => {
          commit('updateList', res)
          resolve(res)
        }).catch(reject)
      })
    },
    getTopList ({ commit }, payload) {
      return new Promise((resolve, reject) => {
        ajax({
          ...api.voteing.list,
          queryData: {
            ...payload,
            tab: 2,
          },
        }).then((res) => {
          commit('updateTopList', res)
          resolve(res)
        }).catch(reject)
      })
    },
  }
}
